==> react-talend-components-0.50.5.tgz: package/src/SidePanel/SidePanel.component.js <==
import React from 'react';
import classNames from 'classnames';
import { Button } from 'react-bootstrap';
import theme from './SidePanel.scss';
import Icon from '../Icon';

/* eslint-disable jsx-a11y/href-no-hash */

/**
 * This component aims to display links as a menu.
 * @param {object} props react props
 *
 @example
 const actions = [
	 { label: 'Preparations', icon: 'fa fa-asterisk', onClick: action('Preparations clicked') },
	 { label: 'Datasets', icon: 'fa fa-file-excel-o', onClick: action('Datasets clicked') },
	 { label: 'Favorites', icon: 'fa fa-star', onClick: action('Favorites clicked') }
 ];
 <SidePanel
	 actions={ actions }
	 onToggleDock={ action('Toggle dock clicked') }
	 docked={ isDocked }
 />
 *
 */
function SidePanel(props) {
	const actions = props.actions || [];

	const dockedCSS = { [theme.docked]: props.docked };
	const navCSS = classNames(
		theme['tc-side-panel'],
		dockedCSS,
		'tc-side-panel'
	);
	const listCSS = classNames(
		'nav nav-pills nav-inverse nav-stacked',
		'tc-side-panel-list',
		theme['action-list']
	);

	return (
		<nav className={navCSS}>
			<ul className={listCSS}>
				<li className="tc-side-panel-list-item">
					<Button
						id={props.id && `${props.id}-toggle-dock`}
						className={classNames(
							theme['toggle-btn'],
							theme.link
						)}
						bsStyle="link"
						onClick={props.onToggleDock}
						aria-hidden="true"
						title="Toggle side panel"
					>
						<Icon name="talend-arrow-left" />
					</Button>
				</li>
				{actions.map(action => (
					<li
						key={action.label}
						className={classNames(
							'tc-side-panel-list-item',
							{ active: !!action.active }
						)}
					>
						<Button
							id={props.id && `${props.id}-nav-${action.label.toLowerCase().split(' ').join('-')}`}
							title={`Display ${action.label}`}
							bsStyle="link"
							role="link"
							className={theme.link}
							onClick={action.onClick}
						>
							{ action.icon ? <Icon name={action.icon} /> : null }
							{ props.docked ? null : <span>{action.label}</span> }
						</Button>
					</li>
				))}
			</ul>
		</nav>
	);
}

SidePanel.propTypes = {
	id: React.PropTypes.string,
	actions: React.PropTypes.arrayOf(
		React.PropTypes.shape({
			label: React.PropTypes.string,
			icon: React.PropTypes.string,
			onClick: React.PropTypes.func,
		})
	),
	onToggleDock: React.PropTypes.func,
	docked: React.PropTypes.bool,
};

export default SidePanel;

==> react-talend-components-0.52.0.tgz: package/src/SidePanel/SidePanel.component.js <==
import React from 'react';
import classNames from 'classnames';
import theme from './SidePanel.scss';
import Action from '../Actions/Action';

/* eslint-disable jsx-a11y/href-no-hash */

/**
 * This component aims to display links as a menu.
 * @param {object} props react props
 *
 @example
 const actions = [
	 { label: 'Preparations', icon: 'fa fa-asterisk', onClick: action('Preparations clicked') },
	 { label: 'Datasets', icon: 'fa fa-file-excel-o', onClick: action('Datasets clicked') },
	 { label: 'Favorites', icon: 'fa fa-star', onClick: action('Favorites clicked') }
 ];
 <SidePanel
	 actions={ actions }
	 onToggleDock={ action('Toggle dock clicked') }
	 docked={ isDocked }
 />
 *
 */
function SidePanel(props) {
	const actions = props.actions || [];

	const dockedCSS = { [theme.docked]: props.docked };
	const navCSS = classNames(
		theme['tc-side-panel'],
		dockedCSS,
		'tc-side-panel'
	);
	const listCSS = classNames(
		'nav nav-pills nav-inverse nav-stacked',
		'tc-side-panel-list',
		theme['action-list']
	);

	return (
		<nav className={navCSS}>
			<ul className={listCSS}>
				<li className={theme['toggle-btn']}>
					<Action
						id={props.id && `${props.id}-toggle-dock`}
						className={theme.link}
						bsStyle="link"
						onClick={props.onToggleDock}
						label="Toggle side panel"
						icon="talend-arrow-left"
						hideLabel
						tooltipPlacement={props.tooltipPlacement}
					/>
				</li>
				{actions.map(action => (
					<li
						key={action.label}
						className={classNames(
							'tc-side-panel-list-item',
							{ active: !!action.active }
						)}
					>
						<Action
							id={props.id && `${props.id}-nav-${action.label.toLowerCase().split(' ').join('-')}`}
							bsStyle="link"
							role="link"
							className={theme.link}
							onClick={action.onClick}
							label={action.label}
							icon={action.icon}
							hideLabel={props.docked}
							tooltipPlacement={props.tooltipPlacement}
						/>
					</li>
				))}
			</ul>
		</nav>
	);
}

SidePanel.propTypes = {
	id: React.PropTypes.string,
	actions: React.PropTypes.arrayOf(
		React.PropTypes.shape({
			label: React.PropTypes.string,
			icon: React.PropTypes.string,
			onClick: React.PropTypes.func,
		})
	),
	onToggleDock: React.PropTypes.func,
	docked: React.PropTypes.bool,
	tooltipPlacement: React.PropTypes.string,
};

SidePanel.defaultProps = {
	tooltipPlacement: 'right',
};
export default SidePanel;
